pyos

package module
v0.0.0-...-29511f1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2021 License: MIT Imports: 5 Imported by: 2

README

pyos

Golang package which contains features similar to the python os module

Current support:

Modules

Python Golang
os.name pyos.Name
os.path.exist() pyos.Path.Exist()
os.path.isfile() pyos.Path.IsFile()
os.path.isdir() pyos.Path.IsDir()

Note: Development in progress

Documentation

Index

Constants

const (
	FileTypeUnknown     = FileType(-2)
	FileTypeNotExist    = FileType(-1)
	FileTypeRegularFile = FileType(0)
	FileTypeDirectory   = FileType(1)
)

See: https://en.wikipedia.org/wiki/Unix_file_types

Variables

var File file
var Path path

Functions

func Name

func Name() string

The name of the operating system dependent module imported. The following names have currently been registered: 'posix', 'nt', 'java'. see: https://docs.python.org/3/library/os.html#os.name

Types

type FileType

type FileType int

Jump to